@@ -1,5 +1,8 @@
-from pymysql import install_as_MySQLdb
-install_as_MySQLdb()
+try:
+    from pymysql import install_as_MySQLdb
+    install_as_MySQLdb()
+except Exception:
+    pass
 
 from .dbpool import init_pool
 from .dbpool import connect_db
@@ -10,3 +13,5 @@ from .table import UpdateTable as Update
 from .table import DeleteTable as Delete
 from .table import InsertTable as Insert
 from .config import settings
+
+__version__ = "0.5.3"
