@@ -4,6 +4,7 @@ import random
 import threading
 import traceback
 from contextlib import contextmanager
+from dbpoolpy.dbconnect.sqlite3 import SQLite3Connection
 from dbpoolpy.dbconnect.mysql import MySQLConnection
 from dbpoolpy.dbconnect.postgresql import PostgreSQLConnection
 from dbpoolpy.dbutil.pooled_db import PooledDB
@@ -40,6 +41,8 @@ class DBPool(DBPoolBase):
             return MySQLConnection
         elif settings.DB_TYPE == DBTYPE.POSTGRESQL:
             return PostgreSQLConnection
+        elif settings.DB_TYPE == DBTYPE.SQLITE3:
+            return SQLite3Connection
 
     def synchronize(func):
         """获取线程锁"""
@@ -58,11 +61,11 @@ class DBPool(DBPoolBase):
         newconns = []
         for i in range(0, n):
             myconn = self._connection_class(
-                self._name, 
-                self._engine, 
-                time.time(), 
-                0, 
-                *self._args, 
+                self._name,
+                self._engine,
+                time.time(),
+                0,
+                *self._args,
                 **self._kwargs)
             myconn.pool = self
             newconns.append(myconn)
@@ -180,8 +183,8 @@ def acquire(name, timeout=10):
         if settings.DEBUG:
             print('name=%s|max_con=%s|con=%s|idle_cache=%s' % (
                 name,
-                con._pool._maxconnections, 
-                con._pool._connections, 
+                con._pool._maxconnections,
+                con._pool._connections,
                 len(con._pool._idle_cache)))
     return con
 
@@ -222,6 +225,42 @@ def connect_db(token):
         if conn:
             release(conn)
 
+# def with_def(db, errfunc=None, errstr=''):
+#     '''数据库连接装饰器,
+#     db: 要连接的数据库:可以用tuple和list连接多个数据库
+#     '''
+#     def f(func):
+#         def _(*args, **kwargs):
+#             multi_db = isinstance(db, (tuple, list))
+#             if multi_db:           # 连接多个数据库
+#                 dbs = {}
+#                 for dbname in db:
+#                     dbs[dbname] = acquire(dbname)
+#                 self = dbs
+#             else:
+#                 self = acquire(db)
+# 
+#             res = None
+#             try:
+#                 res = func(self, *args, **kwargs)
+#             except:
+#                 if errfunc:
+#                     return getattr(self, errfunc)(error=errstr)
+#                 else:
+#                     raise Exception(traceback.format_exc())
+#             finally:
+#                 if multi_db:
+#                     dbs =  self
+#                     dbnames = list(dbs.keys())
+#                     for dbname in dbnames:
+#                         release(dbs.pop(dbname))
+#                 else:
+#                     release(self)
+#                 self = None
+#             return res
+#         return _
+#     return f
+
 
 def with_connect_db(name, errfunc=None, errstr=''):
     '''数据库连接装饰器,可以用在静态方法和类方法里
@@ -234,7 +273,7 @@ def with_connect_db(name, errfunc=None, errstr=''):
             is_class_methed = str(type(self)).startswith("<class '__main__")
             if not is_class_methed and self is not None:
                 raise Exception(
-                    "with_connect_db在装饰静态方法时，方法调用传值首个必须为None, 而不是%s" 
+                    "with_connect_db在装饰静态方法时，方法调用传值首个必须为None, 而不是%s"
                     % str(self))
             if multi_db:           # 连接多个数据库
                 dbs = {}
