@@ -44,7 +44,7 @@ def timeit(func):
 
             print(
                 'server=%s|id=%d|name=%s|user=%s|addr=%s:%d|db=%s|idle=%d|busy=%d|max=%d|trans=%d|time=%d|ret=%s|num=%d|sql=%s|err=%s' % (
-                conn.type, 
+                conn.dbtype, 
                 conn.conn_id % 10000,
                 conn.name, 
                 dbcf.get('user', ''),
@@ -86,12 +86,13 @@ def timesql(func):
                     InternalError:
                         当数据库遇到内部错误时引发的异常，例如游标不再有效、事务不同步等。
                     """
-                    print(traceback.format_exc())
                     if not self._transaction:
                         self.reconnect()
                         continue
+                    print(traceback.format_exc())
                     raise e
                 except Exception as e:
+                    print(traceback.format_exc())
                     raise e
             else:
                 retval = None
